pub enum Status {
NotStarted,
Introduced,
Practicing,
Generalized,
Completed,
DeferredNeedsTrainerNote,
}Expand description
Normalized training milestone status observed from trainer notes or source-data ingestion.
Variants
NotStarted
Staff can see the not started training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.
Introduced
Staff can see the introduced training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.
Practicing
Staff can see the practicing training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.
Generalized
Staff can see the generalized training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.
Completed
Staff can see the completed training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.
DeferredNeedsTrainerNote
Staff can see the deferred needs trainer note training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.